[−][src]Struct flowrstructs::lib_manifest::LibraryManifest
LibraryManifest describes the contents of a Library that can be referenced from a flow
It is provided by libraries to help load and/or find implementations of processes
Fields
metadata: MetaDatametadata about a flow with author, version and usual fields
locators: HashMap<String, ImplementationLocator>the locators map a reference to a function/implementation to the ImplementationLocator
that can be used to load it or reference it
Implementations
impl LibraryManifest[src]
pub fn new(metadata: MetaData) -> Self[src]
Create a new, empty, LibraryManifest with the provided Metadata
pub fn load(
provider: &dyn Provider,
source: &str
) -> Result<(LibraryManifest, String)>[src]
provider: &dyn Provider,
source: &str
) -> Result<(LibraryManifest, String)>
load a library from the source url, using the provider to fetch contents
pub fn add_to_manifest(
&mut self,
base_dir: &str,
wasm_abs_path: &str,
wasm_dir: &str,
function_name: &str
)[src]
&mut self,
base_dir: &str,
wasm_abs_path: &str,
wasm_dir: &str,
function_name: &str
)
Add a function's implementation to the library, specifying path to Wasm for it