[−][src]Enum flowrstructs::input::InputInitializer
An Input can be initialized in one of two ways with an InputInitializer
Variants
Always(Value)A ConstantInputInitializer initializes an input "constantly".
i.e. after each time the associated function is run
Once(Value)A OneTimeInputInitializer initializes an Input once - at start-up before any
functions are run. Then it is not initialized again, unless a reset if done for debugging